unit Unit1;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.StdCtrls, Vcl.ExtCtrls,
  VCLTee.TeEngine, VCLTee.TeeTools, VCLTee.TeeProcs, VCLTee.Chart,
  VCLTee.Series, Generics.Collections;

type
  TDataYear = class
  private
    FValue2: double;
    FValue3: double;
    FValue1: double;
    FValue4: double;
  public
    property Value1: double read FValue1 write FValue1;
    property Value2: double read FValue2 write FValue2;
    property Value3: double read FValue3 write FValue3;
    property Value4: double read FValue4 write FValue4;
  end;

  TDataYears = class(TObjectList<TDataYear>)
  public
    function Add(aYear: TDataYear): integer; overload;
    function Add(const aValue1, aValue2, aValue3, aValue4: double): TDataYear; overload;
  end;
  TForm1 = class(TForm)
    chrActValues: TChart;
    Panel1: TPanel;
    btnCreateSeries: TButton;
    Series1: TBarSeries;
    procedure btnCreateSeriesClick(Sender: TObject);
  private
    { Private declarations }
    FYears: TDataYears;
  public
    constructor Create(aOwner: TComponent); override;
    destructor Destroy; override;

  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}


procedure TForm1.btnCreateSeriesClick(Sender: TObject);

  function CreateBarSeries(aTitle: String): TBarSeries;
  begin
    result := TBarSeries.Create(self);
    result.Title         := aTitle;
    result.BarWidthPercent := 60;
    result.Marks.Visible := false;
    result.SideMargins   := True;
    result.MultiBar      := mbStacked;
    result.ParentChart   := chrActValues;
  end;

  function CreateLineSeries(aTitle: String; aColor: TColor; aChart: TChart = nil): TLineSeries;
  begin
    result                 := TLineSeries.Create(self);
    result.Title           := aTitle;
    result.SeriesColor     := aColor;
    result.Pen.Width       := 2;
    result.Marks.Visible := false;
    if not assigned(aChart) then
      result.ParentChart     := chrActValues
    else
      result.ParentChart := aChart;
  end;

var
  lsrsGrandBenes: TBarSeries;
  lsrsClientValue: TBarSeries;
  lsrsSpouseValue: TBarSeries;
  lsrsBenesValue: TBarSeries;
  I: Integer;
  lYear: TDataYear;
  lIdx: Integer;
begin
{$ifdef CodeSite}
if CSLogging then CodeSite.TraceMethod  (self, 'TframeStretchIRAChart.UpdateDisplay');
{$endif}
  inherited;

  for I := 0 to chrActValues.SeriesCount - 1 do    // Iterate
  begin
    chrActValues.Series[I].Marks.Visible := False;
    chrActValues.Series[I].Marks.Clear;
  end;
  chrActValues.FreeAllSeries;

  //add client series;
  lsrsClientValue := CreateBarSeries('Series 1');
  lsrsClientValue.Marks.Visible := True;
  lsrsSpouseValue := CreateBarSeries('Series 2');
  lsrsSpouseValue.Marks.Visible := True;
  lsrsBenesValue := CreateBarSeries('Series 3');
  lsrsGrandBenes := CreateBarSeries('Series 4');

  lIdx := 2000;

  for lYear in FYears do
  begin
    inc(lIdx);
    lsrsClientValue.AddXY(lIdx, lYear.Value1, IntToStr(lIdx));

    if lYear.Value2 > 0 then
      lsrsSpouseValue.AddXY(lIdx, lYear.Value2, IntToStr(lIdx))
    else
      lsrsSpouseValue.AddNullXY(lIdx, 0);

    if lYear.Value3 > 0 then
      lsrsBenesValue.AddXY(lIdx, lYear.Value3, IntToStr(lIdx))
    else
      lsrsBenesValue.AddNullXY(lIdx, 0);

    if lYear.Value4 > 0 then
      lsrsGrandBenes.AddXY(lIdx, lYear.Value4, IntToStr(lIdx))
    else
      lsrsGrandBenes.AddNullXY(lIdx, 0);
  end;

  chrActValues.Axes.Bottom.LabelStyle:=talValue;
end;

constructor TForm1.Create(aOwner: TComponent);
begin
  inherited;
  FYears := TDataYears.Create;
  FYears.Add(1000, 0, 0, 0);
  FYears.Add(1000, 0, 0, 0);
  FYears.Add(1000, 0, 0, 0);
  FYears.Add(0, 1000, 0, 0);
  FYears.Add(0, 1000, 0, 0);
  FYears.Add(0, 1000, 0, 0);
  FYears.Add(0, 1000, 0, 0);
  FYears.Add(0, 1000, 0, 0);
  FYears.Add(0, 1000, 0, 0);
  FYears.Add(0, 1000, 0, 0);
  FYears.Add(0, 1000, 0, 0);
  FYears.Add(0, 1000, 0, 0);
  FYears.Add(0, 0, 1000, 0);
  FYears.Add(0, 0, 1000, 0);
  FYears.Add(0, 0, 1000, 0);
  FYears.Add(0, 0, 1000, 0);
  FYears.Add(0, 0, 1000, 0);
  FYears.Add(0, 0, 900, 100);
  FYears.Add(0, 0, 900, 100);
  FYears.Add(0, 0, 900, 100);
  FYears.Add(0, 0, 900, 100);
  FYears.Add(0, 0, 900, 100);
  FYears.Add(0, 0, 800, 200);
  FYears.Add(0, 0, 800, 200);
  FYears.Add(0, 0, 800, 200);

  btnCreateSeriesClick(btnCreateSeries);
end;

destructor TForm1.Destroy;
begin
  FYears.Free;

  inherited;
end;

{ TDataYears }

function TDataYears.Add(aYear: TDataYear): integer;
begin
  result := inherited Add(aYear);
end;

function TDataYears.Add(const aValue1, aValue2, aValue3, aValue4: double): TDataYear;
begin
  result := TDataYear.Create;
  result.FValue1 := aValue1;
  result.FValue2 := aValue2;
  result.FValue3 := aValue3;
  result.FValue4 := aValue4;
  Add(result);
end;

end.
